Module: LesliSupport
- Defined in:
- lib/lesli_support/engine.rb,
lib/lesli_support.rb,
lib/lesli_support/version.rb,
app/models/lesli_support/ticket.rb,
app/models/lesli_support/account.rb,
app/models/lesli_support/catalog.rb,
app/models/lesli_support/dashboard.rb,
app/models/lesli_support/items/task.rb,
app/models/lesli_support/catalog/item.rb,
app/jobs/lesli_support/application_job.rb,
app/models/lesli_support/items/activity.rb,
app/models/lesli_support/ticket/activity.rb,
app/helpers/lesli_support/accounts_helper.rb,
app/helpers/lesli_support/catalogs_helper.rb,
app/models/lesli_support/items/discussion.rb,
app/services/lesli_support/ticket_service.rb,
app/models/lesli_support/ticket/discussion.rb,
app/services/lesli_support/catalog_service.rb,
app/helpers/lesli_support/dashboards_helper.rb,
app/models/lesli_support/application_record.rb,
app/helpers/lesli_support/application_helper.rb,
app/mailers/lesli_support/application_mailer.rb,
app/helpers/lesli_support/catalog/items_helper.rb,
app/controllers/lesli_support/tickets_controller.rb,
app/controllers/lesli_support/accounts_controller.rb,
app/controllers/lesli_support/catalogs_controller.rb,
app/helpers/lesli_support/ticket/activities_helper.rb,
app/controllers/lesli_support/dashboards_controller.rb,
app/helpers/lesli_support/ticket/discussions_helper.rb,
app/controllers/lesli_support/application_controller.rb,
app/controllers/lesli_support/items/tasks_controller.rb,
app/controllers/lesli_support/catalog/items_controller.rb,
app/controllers/lesli_support/items/discussions_controller.rb,
app/controllers/lesli_support/ticket/activities_controller.rb,
app/controllers/lesli_support/ticket/discussions_controller.rb
Overview
Lesli
Copyright © 2023, Lesli Technologies, S. A.
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program. If not, see www.gnu.org/licenses/.
Lesli · Ruby on Rails SaaS Development Framework.
Made with ♥ by www.lesli.tech Building a better future, one line of code at a time.
// · ~·~ ~·~ ~·~ ~·~ ~·~ ~·~ ~·~ ~·~ ~·~ // ·
Defined Under Namespace
Modules: AccountsHelper, ApplicationHelper, CatalogsHelper, DashboardsHelper, Items Classes: Account, AccountsController, ApplicationController, ApplicationJob, ApplicationMailer, ApplicationRecord, Catalog, CatalogService, CatalogsController, Dashboard, DashboardsController, Engine, Ticket, TicketService, TicketsController
Constant Summary collapse
- VERSION =
"1.2.0"- BUILD =
"1777174912"